@@ -1,20 +1,29 @@
+"""Extension utilities."""
 import importlib
 import warnings
 
 
 class ExtensionLoadingError(Exception):
+    """An extension loading error."""
+
     pass
 
 
 class ExtensionMetadataError(Exception):
+    """An extension metadata error."""
+
     pass
 
 
 class ExtensionModuleNotFound(Exception):
+    """An extension module not found error."""
+
     pass
 
 
 class NotAnExtensionApp(Exception):
+    """An error raised when a module is not an extension."""
+
     pass
 
 
@@ -26,16 +35,20 @@ def get_loader(obj, logger=None):
     underscore prefix.
     """
     try:
-        func = getattr(obj, '_load_jupyter_server_extension')
+        func = getattr(obj, "_load_jupyter_server_extension")  # noqa B009
     except AttributeError:
-        func = getattr(obj, 'load_jupyter_server_extension')
-        warnings.warn("A `_load_jupyter_server_extension` function was not "
-                "found in {name!s}. Instead, a `load_jupyter_server_extension` "
-                "function was found and will be used for now. This function "
-                "name will be deprecated in future releases "
-                "of Jupyter Server.".format(name=obj), DeprecationWarning)
+        func = getattr(obj, "load_jupyter_server_extension", None)
+        warnings.warn(
+            "A `_load_jupyter_server_extension` function was not "
+            "found in {name!s}. Instead, a `load_jupyter_server_extension` "
+            "function was found and will be used for now. This function "
+            "name will be deprecated in future releases "
+            "of Jupyter Server.".format(name=obj),
+            DeprecationWarning,
+        )
     except Exception:
-        raise ExtensionLoadingError("_load_jupyter_server_extension function was not found.")
+        msg = "_load_jupyter_server_extension function was not found."
+        raise ExtensionLoadingError(msg) from None
     return func
 
 
@@ -82,10 +95,7 @@ def get_metadata(package_name, logger=None):
             "for extension points in the extension pacakge's "
             "root.".format(name=package_name)
         )
-    return module, [{
-        "module": package_name,
-        "name": package_name
-    }]
+    return module, [{"module": package_name, "name": package_name}]
 
 
 def validate_extension(name):
@@ -99,4 +109,5 @@ def validate_extension(name):
     If this works, nothing should happen.
     """
     from .manager import ExtensionPackage
+
     return ExtensionPackage(name=name)
