@@ -34,6 +34,7 @@ _script_exporter = None
 
 
 class FileContentsManager(FileManagerMixin, ContentsManager):
+    """A file contents manager."""
 
     root_dir = Unicode(config=True)
 
@@ -46,7 +47,6 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
     @validate("root_dir")
     def _validate_root_dir(self, proposal):
-        """Do a bit of validation of the root_dir."""
         value = proposal["value"]
         if not os.path.isabs(value):
             # If we receive a non-absolute path, make it absolute.
@@ -395,6 +395,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
             if type == "directory":
                 raise web.HTTPError(400, "%s is not a directory" % path, reason="bad type")
             model = self._file_model(path, content=content, format=format)
+        self.emit(data={"action": "get", "path": path})
         return model
 
     def _save_directory(self, os_path, model, path=""):
@@ -459,7 +460,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
             model["message"] = validation_message
 
         self.run_post_save_hooks(model=model, os_path=os_path)
-
+        self.emit(data={"action": "save", "path": path})
         return model
 
     def delete_file(self, path):
@@ -467,14 +468,14 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         path = path.strip("/")
         os_path = self._get_os_path(path)
         rm = os.unlink
-        four_o_four = "file or directory does not exist: %r" % path
-
-        if not self.exists(path):
-            raise web.HTTPError(404, four_o_four)
 
         if is_hidden(os_path, self.root_dir) and not self.allow_hidden:
             raise web.HTTPError(400, f"Cannot delete file or directory {os_path!r}")
 
+        four_o_four = "file or directory does not exist: %r" % path
+        if not self.exists(path):
+            raise web.HTTPError(404, four_o_four)
+
         def _check_trash(os_path):
             if sys.platform in {"win32", "darwin"}:
                 return True
@@ -557,6 +558,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
             raise web.HTTPError(500, f"Unknown error renaming file: {old_path} {e}") from e
 
     def info_string(self):
+        """Get the information string for the manager."""
         return _i18n("Serving notebooks from local directory: %s") % self.root_dir
 
     def get_kernel_path(self, path, model=None):
@@ -571,6 +573,8 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
 
 class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, AsyncContentsManager):
+    """An async file contents manager."""
+
     @default("checkpoints_class")
     def _checkpoints_class_default(self):
         return AsyncFileCheckpoints
@@ -735,6 +739,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
             if type == "directory":
                 raise web.HTTPError(400, "%s is not a directory" % path, reason="bad type")
             model = await self._file_model(path, content=content, format=format)
+        self.emit(data={"action": "get", "path": path})
         return model
 
     async def _save_directory(self, os_path, model, path=""):
@@ -753,7 +758,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         """Save the file model and return the model with no content."""
         path = path.strip("/")
 
-        self.run_pre_save_hook(model=model, path=path)
+        self.run_pre_save_hooks(model=model, path=path)
 
         if "type" not in model:
             raise web.HTTPError(400, "No file type provided")
@@ -795,7 +800,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
             model["message"] = validation_message
 
         self.run_post_save_hooks(model=model, os_path=os_path)
-
+        self.emit(data={"action": "save", "path": path})
         return model
 
     async def delete_file(self, path):
@@ -803,6 +808,10 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         path = path.strip("/")
         os_path = self._get_os_path(path)
         rm = os.unlink
+
+        if is_hidden(os_path, self.root_dir) and not self.allow_hidden:
+            raise web.HTTPError(400, f"Cannot delete file or directory {os_path!r}")
+
         if not os.path.exists(os_path):
             raise web.HTTPError(404, "File or directory does not exist: %s" % os_path)
 
@@ -874,6 +883,11 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         new_os_path = self._get_os_path(new_path)
         old_os_path = self._get_os_path(old_path)
 
+        if (
+            is_hidden(old_os_path, self.root_dir) or is_hidden(new_os_path, self.root_dir)
+        ) and not self.allow_hidden:
+            raise web.HTTPError(400, f"Cannot rename file or directory {old_os_path!r}")
+
         # Should we proceed with the move?
         if os.path.exists(new_os_path) and not samefile(old_os_path, new_os_path):
             raise web.HTTPError(409, "File already exists: %s" % new_path)
@@ -904,3 +918,13 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         path = path.strip("/")
         os_path = self._get_os_path(path=path)
         return is_hidden(os_path, self.root_dir)
+
+    async def get_kernel_path(self, path, model=None):
+        """Return the initial API path of a kernel associated with a given notebook"""
+        if await self.dir_exists(path):
+            return path
+        if "/" in path:
+            parent_dir = path.rsplit("/", 1)[0]
+        else:
+            parent_dir = ""
+        return parent_dir
