@@ -43,6 +43,7 @@ class KernelSessionRecord:
     kernel_id: Union[None, str] = None
 
     def __eq__(self, other: object) -> bool:
+        """Whether a record equals another."""
         if isinstance(other, KernelSessionRecord):
             condition1 = self.kernel_id and self.kernel_id == other.kernel_id
             condition2 = all(
@@ -63,24 +64,25 @@ class KernelSessionRecord:
                     self.kernel_id != other.kernel_id,
                 ]
             ):
-                raise KernelSessionRecordConflict(
+                msg = (
                     "A single session_id can only have one kernel_id "
                     "associated with. These two KernelSessionRecords share the same "
                     "session_id but have different kernel_ids. This should "
                     "not be possible and is likely an issue with the session "
                     "records."
                 )
+                raise KernelSessionRecordConflict(msg)
         return False
 
     def update(self, other: "KernelSessionRecord") -> None:
         """Updates in-place a kernel from other (only accepts positive updates"""
         if not isinstance(other, KernelSessionRecord):
-            raise TypeError("'other' must be an instance of KernelSessionRecord.")
+            msg = "'other' must be an instance of KernelSessionRecord."
+            raise TypeError(msg)
 
         if other.kernel_id and self.kernel_id and other.kernel_id != self.kernel_id:
-            raise KernelSessionRecordConflict(
-                "Could not update the record from 'other' because the two records conflict."
-            )
+            msg = "Could not update the record from 'other' because the two records conflict."
+            raise KernelSessionRecordConflict(msg)
 
         for field in fields(self):
             if hasattr(other, field.name) and getattr(other, field.name):
@@ -97,11 +99,13 @@ class KernelSessionRecordList:
     """
 
     def __init__(self, *records):
+        """Initialize a record list."""
         self._records = []
         for record in records:
             self.update(record)
 
     def __str__(self):
+        """The string representation of a record list."""
         return str(self._records)
 
     def __contains__(self, record: Union[KernelSessionRecord, str]) -> bool:
@@ -116,6 +120,7 @@ class KernelSessionRecordList:
         return False
 
     def __len__(self):
+        """The length of the record list."""
         return len(self._records)
 
     def get(self, record: Union[KernelSessionRecord, str]) -> KernelSessionRecord:
@@ -130,7 +135,8 @@ class KernelSessionRecordList:
             for r in self._records:
                 if record == r:
                     return record
-        raise ValueError(f"{record} not found in KernelSessionRecordList.")
+        msg = f"{record} not found in KernelSessionRecordList."
+        raise ValueError(msg)
 
     def update(self, record: KernelSessionRecord) -> None:
         """Update a record in-place or append it if not in the list."""
@@ -149,6 +155,7 @@ class KernelSessionRecordList:
 
 
 class SessionManager(LoggingConfigurable):
+    """A session manager."""
 
     database_filepath = Unicode(
         default_value=":memory:",
@@ -162,6 +169,7 @@ class SessionManager(LoggingConfigurable):
 
     @validate("database_filepath")
     def _validate_database_filepath(self, proposal):
+        """Validate a database file path."""
         value = proposal["value"]
         if value == ":memory:":
             return value
@@ -169,15 +177,15 @@ class SessionManager(LoggingConfigurable):
         if path.exists():
             # Verify that the database path is not a directory.
             if path.is_dir():
-                raise TraitError(
-                    "`database_filepath` expected a file path, but the given path is a directory."
-                )
+                msg = "`database_filepath` expected a file path, but the given path is a directory."
+                raise TraitError(msg)
             # Verify that database path is an SQLite 3 Database by checking its header.
             with open(value, "rb") as f:
                 header = f.read(100)
 
             if not header.startswith(b"SQLite format 3") and not header == b"":
-                raise TraitError("The given file is not an SQLite database file.")
+                msg = "The given file is not an SQLite database file."
+                raise TraitError(msg)
         return value
 
     kernel_manager = Instance("jupyter_server.services.kernels.kernelmanager.MappingKernelManager")
@@ -189,6 +197,7 @@ class SessionManager(LoggingConfigurable):
     )
 
     def __init__(self, *args, **kwargs):
+        """Initialize a record list."""
         super().__init__(*args, **kwargs)
         self._pending_sessions = KernelSessionRecordList()
 
@@ -335,12 +344,14 @@ class SessionManager(LoggingConfigurable):
             session described by the kwarg.
         """
         if not kwargs:
-            raise TypeError("must specify a column to query")
+            msg = "must specify a column to query"
+            raise TypeError(msg)
 
         conditions = []
         for column in kwargs.keys():
             if column not in self._columns:
-                raise TypeError("No such column: %r", column)
+                msg = f"No such column: {column}"
+                raise TypeError(msg)
             conditions.append("%s=?" % column)
 
         query = "SELECT * FROM session WHERE %s" % (" AND ".join(conditions))
